# New in 0.7.0 (2020-10-14)

scvi is now scvi-tools. Version 0.7 introduces many breaking changes. The best way to learn how to use scvi-tools is with our documentation and tutorials.

-   New high-level API and data loading, please see tutorials and examples for usage.
-   `GeneExpressionDataset` and associated classes have been removed.
-   Built-in datasets now return `AnnData` objects.
-   `scvi-tools` now relies entirely on the [AnnData] format.
-   `scvi.models` has been moved to `scvi.core.module`.
-   `Posterior` classes have been reduced to wrappers on `DataLoaders`
-   `scvi.inference` has been split to `scvi.core.data_loaders` for `AnnDataLoader` classes and `scvi.core.trainers` for trainer classes.
-   Usage of classes like `Trainer` and `AnnDataLoader` now require the `AnnData` data object as input.
